@@ -25,8 +25,8 @@ class AirNowUploaderConf(SFTPClientConf, PersistentJSONable):
     __FILENAME = "airnow_uploader_conf.json"
 
     @classmethod
-    def persistence_location(cls, host):
-        return host.conf_dir(), cls.__FILENAME
+    def persistence_location(cls):
+        return cls.conf_dir(), cls.__FILENAME
 
 
     # ----------------------------------------------------------------------------------------------------------------
