@@ -53,7 +53,7 @@ class Project(PersistentJSONable):
 
 
     @classmethod
-    def construct_from_jdict(cls, jdict, default=True):
+    def construct_from_jdict(cls, jdict, skeleton=False):
         if not jdict:
             return None
 
@@ -69,6 +69,8 @@ class Project(PersistentJSONable):
         """
         Constructor
         """
+        super().__init__()
+
         self.__location_path = location_path          # string
         self.__device_path = device_path              # string
 
