@@ -28,7 +28,7 @@ class PowerList(PersistentJSONable):
 
 
     @classmethod
-    def construct_from_jdict(cls, jdict, default=True):
+    def construct_from_jdict(cls, jdict, skeleton=False):
         if not jdict:
             return None
 
@@ -43,6 +43,8 @@ class PowerList(PersistentJSONable):
         """
         Constructor
         """
+        super().__init__()
+
         self.__power_list = power_list
 
     # ----------------------------------------------------------------------------------------------------------------
