@@ -31,7 +31,30 @@ class LocalizedDatetime(JSONable):
     classdocs
     """
 
-    OLE_TIME_ZERO = datetime(1899, 12, 30, 0, 0, 0)
+    OLE_TIME_ZERO = datetime(1899, month=12, day=30)
+
+    MONTH_NAMES = {
+        'jan': 1,
+        'feb': 2,
+        'mar': 3,
+        'apr': 4,
+        'may': 5,
+        'jun': 6,
+        'jul': 7,
+        'aug': 8,
+        'sep': 9,
+        'oct': 10,
+        'nov': 11,
+        'dec': 12
+    }
+
+    @classmethod
+    def month(cls, name):
+        try:
+            return cls.MONTH_NAMES[name.lower()]
+        except KeyError:
+            raise ValueError(name)
+
 
     # ----------------------------------------------------------------------------------------------------------------
 
@@ -46,7 +69,7 @@ class LocalizedDatetime(JSONable):
     @classmethod
     def construct_from_date(cls, date):
         zone = tzlocal.get_localzone()
-        localized = zone.localize(datetime(date.year, date.month, date.day))
+        localized = zone.localize(datetime(date.year, month=date.month, day=date.day))
 
         return LocalizedDatetime(localized)
 
@@ -83,7 +106,7 @@ class LocalizedDatetime(JSONable):
             return None
 
         # time (rightmost time in string)...
-        match = re.match(r'(\d{2}):(\d{2})(:(\d{2}))? *([APap][Mm])? *$', time_str)       # e.g. 24:00:00
+        match = re.match(r'(\d{1,2}):(\d{2})(:(\d{2}))? *([APap][Mm])? *$', time_str)       # e.g. 24:00:00
 
         if match is None:
             return None
@@ -108,6 +131,34 @@ class LocalizedDatetime(JSONable):
         return corrected
 
 
+    @classmethod
+    def construct_from_s3(cls, datetime_str):       # Sat, 11 Sep 2021 08:47:47 GMT
+        # match...
+        match = re.match(r'\S{3}, (\d{1,2}) (\S{3}) (\d{4}) (\d{2}):(\d{2}):(\d{2}) GMT', datetime_str)
+
+        if match is None:
+            return None
+
+        fields = match.groups()
+
+        # fields...
+        year = int(fields[2])
+        month = cls.month(fields[1])
+        day = int(fields[0])
+
+        hour = int(fields[3])
+        minute = int(fields[4])
+        second = int(fields[5])
+
+        # construct...
+        zone_offset = timedelta(hours=0, minutes=0)
+        zone = timezone(zone_offset)
+
+        localized = datetime(year, month=month, day=day, hour=hour, minute=minute, second=second, tzinfo=zone)
+
+        return LocalizedDatetime(localized)
+
+
     @classmethod
     def construct_from_oad(cls, oad, tz=None):
         date = cls.OLE_TIME_ZERO + timedelta(days=float(oad))
@@ -150,7 +201,8 @@ class LocalizedDatetime(JSONable):
         zone_offset = timedelta(hours=0, minutes=0)
         zone = timezone(zone_offset)
 
-        localized = datetime(year, month, day, hour, minute, second, micros, tzinfo=zone)
+        localized = datetime(year, month=month, day=day, hour=hour, minute=minute, second=second, microsecond=micros,
+                             tzinfo=zone)
 
         return LocalizedDatetime(localized)
 
@@ -184,7 +236,8 @@ class LocalizedDatetime(JSONable):
         zone_offset = zone_sign * timedelta(hours=zone_hours, minutes=zone_mins)
         zone = timezone(zone_offset)
 
-        localized = datetime(year, month, day, hour, minute, second, micros, tzinfo=zone)
+        localized = datetime(year, month=month, day=day, hour=hour, minute=minute, second=second, microsecond=micros,
+                             tzinfo=zone)
 
         return LocalizedDatetime(localized)
 
