@@ -18,8 +18,6 @@ from scs_core.data.str import Str
 from scs_core.gas.sensor_baseline import SensorBaseline
 
 
-# TODO: rename as Interface Baseline (GSBaseline)
-
 # --------------------------------------------------------------------------------------------------------------------
 
 class AFEBaseline(PersistentJSONable):
@@ -50,7 +48,7 @@ class AFEBaseline(PersistentJSONable):
         for i in range(len(jdict)):
             key = 'sn' + str(i + 1)
 
-            base = SensorBaseline.construct_from_jdict(jdict[key]) if key in jdict else SensorBaseline(None, 0, None)
+            base = SensorBaseline.construct_from_jdict(jdict[key]) if key in jdict else SensorBaseline(None, 0)
             sensor_baselines.append(base)
 
         return cls(sensor_baselines)
@@ -58,7 +56,7 @@ class AFEBaseline(PersistentJSONable):
 
     @classmethod
     def null_datum(cls):
-        return cls([SensorBaseline(None, 0, None)] * cls.__SENSORS)
+        return cls([SensorBaseline(None, 0)] * cls.__SENSORS)
 
 
     # ----------------------------------------------------------------------------------------------------------------
