@@ -30,7 +30,7 @@ class GPSDatum(JSONReport):
     # ----------------------------------------------------------------------------------------------------------------
 
     @classmethod
-    def construct_from_jdict(cls, jdict, default=True):
+    def construct_from_jdict(cls, jdict, skeleton=False):
         if not jdict:
             return cls.null_datum()
 
