@@ -4,15 +4,11 @@ Created on 20 Oct 2016
 @author: Bruno Beloff (bruno.beloff@southcoastscience.com)
 
 example document:
-{"tag": "scs-be2-2",
- "rec": "2017-09-24T07:51:21Z",
- "val": {
-  "NO2": {"weV": 0.312317, "aeV": 0.31038, "weC": -0.001, "cnc": 14.8},
-  "CO": {"weV": 0.325005, "aeV": 0.254254, "weC": 0.077239, "cnc": 323.2},
-  "SO2": {"weV": 0.277942, "aeV": 0.267754, "weC": 0.004136, "cnc": 27.6},
-  "H2S": {"weV": 0.221816, "aeV": 0.269817, "weC": -0.006301, "cnc": 29.6},
-  "pt1": {"v": 0.321411, "tmp": 21.9},
-  "sht": {"hmd": 73.0, "tmp": 21.4}}}
+{"rec": "2021-10-11T10:59:40Z", "tag": "scs-be2-3", "ver": 2.0, "src": "AFE",
+"val": {"NO2": {"weV": 0.29057, "aeV": 0.29544, "weC": 0.00131, "cnc": 20.9, "vCal": 15.41},
+"Ox": {"weV": 0.40101, "aeV": 0.39969, "weC": 0.00235, "cnc": 55.7, "vCal": 6.61, "xCal": -0.390731},
+"CO": {"weV": 0.44069, "aeV": 0.30213, "weC": 0.16795, "cnc": 685.4, "vCal": 562.256},
+"sht": {"hmd": 52.9, "tmp": 21.9}}, "exg": {"src": "vB20", "val": {"NO2": {"cnc": 19.3}}}}
 """
 
 from collections import OrderedDict
@@ -22,7 +18,7 @@ from scs_core.climate.sht_datum import SHTDatum
 from scs_core.data.datetime import LocalizedDatetime
 from scs_core.data.str import Str
 
-from scs_core.gas.a4.a4_datum import A4Datum
+from scs_core.gas.a4.a4_calibrated_datum import A4CalibratedDatum
 from scs_core.gas.afe.afe_datum import AFEDatum
 from scs_core.gas.afe.pt1000_datum import Pt1000Datum
 from scs_core.gas.pid.pid import PIDDatum
@@ -31,8 +27,6 @@ from scs_core.gas.scd30.scd30_datum import SCD30Datum
 from scs_core.sample.sample import Sample
 
 
-# TODO: get src from AFE / ISI datum?
-
 # --------------------------------------------------------------------------------------------------------------------
 
 class GasesSample(Sample):
@@ -40,8 +34,12 @@ class GasesSample(Sample):
     classdocs
     """
 
-    __NON_ELECTROCHEM_FIELDS = ['pt1', 'sht', 'CO2', 'VOC']
-    __VOC_FIELDS = ['VOC']
+    VERSION = 1.0
+
+    __NON_ELECTROCHEM_FIELDS = ('pt1', 'sht', 'CO2', 'VOC', 'VOCe')
+    __VOC_FIELDS = ('VOC', 'VOCe')
+
+    # ----------------------------------------------------------------------------------------------------------------
 
     @classmethod
     def construct_from_jdict(cls, jdict, skeleton=False):
@@ -49,8 +47,11 @@ class GasesSample(Sample):
             return None
 
         # Sample...
-        rec = LocalizedDatetime.construct_from_jdict(jdict.get('rec'))
         tag = jdict.get('tag')
+        rec = LocalizedDatetime.construct_from_jdict(jdict.get('rec'))
+        version = jdict.get('ver', cls.DEFAULT_VERSION)
+
+        src = jdict.get('src')
         val = jdict.get('val')
         exegeses = jdict.get('exg')
 
@@ -68,37 +69,38 @@ class GasesSample(Sample):
 
         for field, node in val.items():
             if field not in cls.__NON_ELECTROCHEM_FIELDS:
-                sns[field] = A4Datum.construct_from_jdict(node)
+                sns[field] = A4CalibratedDatum.construct_from_jdict(node)
 
             if field in cls.__VOC_FIELDS:
                 sns[field] = PIDDatum.construct_from_jdict(node)
 
         electrochem_datum = AFEDatum(pt1000_datum, *list(sns.items()))
 
-        return cls(tag, rec, scd30_datum, electrochem_datum, sht_datum, exegeses=exegeses)
+        return cls(tag, rec, scd30_datum, electrochem_datum, sht_datum, version=version, src=src, exegeses=exegeses)
 
 
-    # ----------------------------------------------------------------------------------------------------------------
-
-    def __init__(self, tag, rec, scd30_datum, electrochem_datum, sht_datum, exegeses=None):
-        """
-        Constructor
-        """
-        super().__init__(tag, rec, exegeses=exegeses)
-
-        self.__scd30_datum = scd30_datum                            # SCD30Datum
-        self.__electrochem_datum = electrochem_datum                # AFEDatum or ISIDatum
-        self.__sht_datum = sht_datum                                # SHT31Datum
-
-
-    # ----------------------------------------------------------------------------------------------------------------
-
     @classmethod
     def has_invalid_value(cls):
         # TODO: implement has_invalid_value
         return False
 
 
+    # ----------------------------------------------------------------------------------------------------------------
+
+    def __init__(self, tag, rec, scd30_datum, electrochem_datum, sht_datum, version=None, src=None, exegeses=None):
+        """
+        Constructor
+        """
+        if version is None:
+            version = self.VERSION
+
+        super().__init__(tag, rec, version, src=src, exegeses=exegeses)
+
+        self.__scd30_datum = scd30_datum                            # SCD30Datum
+        self.__electrochem_datum = electrochem_datum                # AFEDatum or ISIDatum
+        self.__sht_datum = sht_datum                                # SHT31Datum
+
+
     # ----------------------------------------------------------------------------------------------------------------
 
     @property
@@ -146,5 +148,7 @@ class GasesSample(Sample):
     def __str__(self, *args, **kwargs):
         exegeses = Str.collection(self.exegeses)
 
-        return "GasesSample:{tag:%s, rec:%s, exegeses:%s, scd30_datum:%s, electrochem_datum:%s, sht_datum:%s}" % \
-            (self.tag, self.rec, exegeses, self.scd30_datum, self.electrochem_datum, self.sht_datum)
+        return "GasesSample:{tag:%s, rec:%s, src:%s, exegeses:%s, " \
+               "scd30_datum:%s, electrochem_datum:%s, sht_datum:%s}" % \
+            (self.tag, self.rec, self.src, exegeses,
+             self.scd30_datum, self.electrochem_datum, self.sht_datum)
