@@ -33,10 +33,10 @@ class Node(ABC):
 
     @staticmethod
     def ipv4_address():
-        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+        s = socket.socket(family=socket.AF_INET, type=socket.SOCK_DGRAM)
 
         try:
-            s.connect(('192.168.0.1', 1))  # host does not need to be reachable
+            s.connect(('192.168.0.1', 1))           # host does not need to be reachable
             dot_decimal = s.getsockname()[0]
 
         except OSError:
@@ -126,6 +126,25 @@ class IoTNode(Node):
     classdocs
     """
 
+    # ----------------------------------------------------------------------------------------------------------------
+    # identity...
+
+    @classmethod
+    def numeric_component_of_name(cls):
+        hostname = socket.gethostname()
+        pieces = hostname.split('-')
+
+        if len(pieces) != 3:
+            raise ValueError(hostname)
+
+        try:
+            numeric_component = int(pieces[2])
+        except ValueError:
+            raise ValueError(hostname)
+
+        return numeric_component
+
+
     # ----------------------------------------------------------------------------------------------------------------
     # status...
 
@@ -134,6 +153,33 @@ class IoTNode(Node):
         pass
 
 
+    # ----------------------------------------------------------------------------------------------------------------
+    # networks and modem...
+
+    @classmethod
+    @abstractmethod
+    def networks(cls):
+        pass
+
+
+    @classmethod
+    @abstractmethod
+    def modem(cls):
+        pass
+
+
+    @classmethod
+    @abstractmethod
+    def modem_conn(cls):
+        pass
+
+
+    @classmethod
+    @abstractmethod
+    def sim(cls):
+        pass
+
+
     # ----------------------------------------------------------------------------------------------------------------
     # SPI...
 
